Package: ModelMetrics
Title: Rapid Calculation of Model Metrics
Version: 1.2.2.2
Date: 2018-11-03
Authors@R: person("Tyler", "Hunt", email = "thunt@snapfinance.com", role = c("aut", "cre"))
Description: Collection of metrics for evaluating models written in C++ using 'Rcpp'. Popular metrics include area under the curve, log loss, root mean square error, etc.
Depends: R (>= 3.2.2)
License: GPL (>= 2)
Encoding: UTF-8
LazyData: true
LinkingTo: Rcpp
Imports: Rcpp, data.table
RoxygenNote: 6.0.1
Suggests: testthat
NeedsCompilation: yes
Packaged: 2020-03-17 06:58:01 UTC; ripley
Author: Tyler Hunt [aut, cre]
Maintainer: Tyler Hunt <thunt@snapfinance.com>
Repository: CRAN
Date/Publication: 2020-03-17 07:45:31 UTC
Built: R 4.4.0; amd64-portbld-midnightbsd4; 2026-07-19 01:12:40 UTC; unix

# Generated by roxygen2: do not edit by hand

S3method(auc,default)
S3method(auc,gbm)
S3method(auc,glm)
S3method(auc,glmerMod)
S3method(auc,randomForest)
S3method(auc,rpart)
S3method(brier,default)
S3method(brier,gbm)
S3method(brier,glm)
S3method(brier,glmerMod)
S3method(brier,randomForest)
S3method(brier,rpart)
S3method(ce,default)
S3method(ce,gbm)
S3method(ce,glm)
S3method(ce,glmerMod)
S3method(ce,lm)
S3method(ce,randomForest)
S3method(ce,rpart)
S3method(gini,default)
S3method(gini,gbm)
S3method(gini,glm)
S3method(gini,glmerMod)
S3method(gini,randomForest)
S3method(gini,rpart)
S3method(logLoss,default)
S3method(logLoss,gbm)
S3method(logLoss,glm)
S3method(logLoss,glmerMod)
S3method(logLoss,randomForest)
S3method(logLoss,rpart)
S3method(mae,default)
S3method(mae,gbm)
S3method(mae,glm)
S3method(mae,glmerMod)
S3method(mae,randomForest)
S3method(mae,rpart)
S3method(mse,default)
S3method(mse,glm)
S3method(mse,lm)
S3method(msle,default)
S3method(msle,gbm)
S3method(msle,glm)
S3method(msle,glmerMod)
S3method(msle,lm)
S3method(msle,randomForest)
S3method(msle,rpart)
S3method(rmse,default)
S3method(rmse,glm)
S3method(rmse,lm)
S3method(rmsle,default)
S3method(rmsle,gbm)
S3method(rmsle,glm)
S3method(rmsle,glmerMod)
S3method(rmsle,lm)
S3method(rmsle,randomForest)
S3method(rmsle,rpart)
export(auc)
export(brier)
export(ce)
export(confusionMatrix)
export(f1Score)
export(fScore)
export(gini)
export(kappa)
export(logLoss)
export(mae)
export(mauc)
export(mcc)
export(mlogLoss)
export(mse)
export(msle)
export(npv)
export(ppv)
export(precision)
export(recall)
export(rmse)
export(rmsle)
export(sensitivity)
export(specificity)
export(tnr)
export(tpr)
importFrom(Rcpp,sourceCpp)
importFrom(data.table,frankv)
importFrom(data.table,fsort)
importFrom(stats,predict)
useDynLib(ModelMetrics)

## ModelMetrics: Rapid Calculation of Model Metrics
[![Build Status](https://travis-ci.org/JackStat/ModelMetrics.svg?branch=master)](https://travis-ci.org/JackStat/ModelMetrics)
[![Build status](https://ci.appveyor.com/api/projects/status/evm55ctrlwp6fjs3/branch/master?svg=true)](https://ci.appveyor.com/project/JackStat/modelmetrics/branch/master)
[![Coverage Status](https://coveralls.io/repos/github/JackStat/ModelMetrics/badge.svg?branch=master)](https://coveralls.io/github/JackStat/ModelMetrics?branch=master)
[![Downloads](https://cranlogs.r-pkg.org/badges/ModelMetrics)](https://CRAN.R-project.org/package=ModelMetrics)

Tyler Hunt thunt@snapfinance.com

### Introduction
ModelMetrics is a much faster and reliable package for evaluating models. ModelMetrics is written in using Rcpp making it faster than the other packages used for model metrics.


### Installation

You can install this package from CRAN:

```r
install.packages("ModelMetrics")
```

Or you can install the development version from Github with [devtools](https://github.com/hadley/devtools):

```r
devtools::install_github("JackStat/ModelMetrics")
```


### Benchmark and comparison

```r
N = 100000
Actual = as.numeric(runif(N) > .5)
Predicted = as.numeric(runif(N))

actual = Actual
predicted = Predicted

s1 <- system.time(a1 <- ModelMetrics::auc(Actual, Predicted))
s2 <- system.time(a2 <- Metrics::auc(Actual, Predicted))
# Warning message:
# In n_pos * n_neg : NAs produced by integer overflow
s3 <- system.time(a3 <- pROC::auc(Actual, Predicted))
s4 <- system.time(a4 <- MLmetrics::AUC(Predicted, Actual))
# Warning message:
# In n_pos * n_neg : NAs produced by integer overflow
s5 <- system.time({pp <- ROCR::prediction(Predicted, Actual); a5 <- ROCR::performance(pp, 'auc')})


data.frame(
  package = c("ModelMetrics", "pROC", "ROCR")
  ,Time = c(s1[[3]],s3[[3]],s5[[3]])
)

# MLmetrics and Metrics could not calculate so they are dropped from time comparison
#        package   Time
# 1 ModelMetrics  0.030
# 2         pROC 50.359
# 3         ROCR  0.358
```

#' @title Log Loss
#'
#' @description Calculates the log loss or entropy loss for a binary outcome
#'
#' @param actual a binary vector of the labels
#' @param predicted a vector of predicted values
#' @param distribution the distribution of the loss function needed \code{binomial, poisson}
#' @param \dots additional parameters to be passed the the s3 methods
#' @param modelObject the model object. Currently supported \code{glm, randomForest, glmerMod, gbm}
#'
#' @examples
#' data(testDF)
#' glmModel <- glm(y ~ ., data = testDF, family="binomial")
#' Preds <- predict(glmModel, type = 'response')
#'
#' logLoss(testDF$y, Preds)
#' # using s3 method for glm
#' logLoss(glmModel)
#'
#' @export

logLoss <- function(...){
  UseMethod("logLoss")
}

#' @rdname logLoss
#' @export
logLoss.default <- function(actual, predicted, distribution = "binomial", ...){

  eps <- 1e-15
  predicted = pmax(pmin(predicted, 1 - eps), eps)

  if(distribution == "binomial"){

    return(logLoss_(actual, predicted))

  } else if(distribution == 'poisson'){

    return(plogLoss_(actual, predicted))

  } else {
    stop(paste(distribution, "is not defined. Please use binomial or poisson"))
  }

}

#' @rdname logLoss
#' @export
logLoss.glm <- function(modelObject, ...){

  family <- family(modelObject)[[1]]
  if(any(family %in% c('binomial', 'poisson'))){
    actual <- modelObject$y
    predicted <- modelObject$fitted.values
  } else {
    stop(paste0("family: ", family, " is not currently supported"))
  }

  logLoss.default(actual, predicted, distribution = family)
}

#' @importFrom stats predict
#' @rdname logLoss
#' @export
logLoss.randomForest <- function(modelObject, ...){

  actual <- as.numeric(modelObject$y) - 1
  predicted <- predict(modelObject, type = 'prob')[,2]

  logLoss.default(actual, predicted)
}

#' @rdname logLoss
#' @export
logLoss.glmerMod <- function(modelObject, ...){

  actual <- modelObject@resp$y
  predicted <- modelObject@resp$mu

  logLoss.default(actual, predicted)
}

#' @rdname logLoss
#' @export
logLoss.gbm <- function(modelObject, ...){

  actual <- modelObject$data$y
  predicted <- modelObject$fit

  logLoss.default(actual, predicted)
}

#' @rdname logLoss
#' @export
logLoss.rpart <- function(modelObject, ...){

  actual <- modelObject$y
  predicted <- predict(modelObject)

  logLoss.default(actual, predicted)
}

context("Error Messages")


test_that("Error messages are correct", {

  Actual = sample(c(0,1), 10, replace = TRUE)
  Predicted = runif(10)
  expect_error(logLoss(Actual, Predicted, distribution = "exp")
               ,'exp is not defined. Please use binomial or poisson')

  expect_silent(logLoss(Actual, Predicted, distribution = "binomial"))

  expect_silent(logLoss(Actual, Predicted, distribution = "poisson"))

})

#' @title Area Under the Curve
#'
#' @description Calculates the area under the curve for a binary classifcation model
#'
#' @param actual A vector of the labels. Can be \code{numeric, character, or factor}
#' @param predicted A vector of predicted values
#' @param \dots additional parameters to be passed the the s3 methods
#' @param modelObject the model object. Currently supported \code{glm, randomForest, glmerMod, gbm}
#'
#' @examples
#' data(testDF)
#' glmModel <- glm(y ~ ., data = testDF, family="binomial")
#' Preds <- predict(glmModel, type = 'response')
#'
#' auc(testDF$y, Preds)
#' # using s3 method for glm
#' auc(glmModel)
#'
#'
#' @export

auc <- function(...){
  UseMethod("auc")
}

#' @importFrom data.table frankv
#' @rdname auc
#' @export
auc.default <- function(actual, predicted, ...){

  binaryChecks(actual, 'auc')

  if (inherits(actual, 'factor')) {
    actual <- as.integer(actual) - 1L
  } else if (inherits(actual, 'character')) {
    actual <- as.integer(as.factor(actual)) - 1L
  }

  if(length(actual > 10000)){
    ranks = frankv(predicted)
    AUC <- auc3_(actual, predicted, ranks)
  } else {
    AUC <- auc_(actual, predicted)
  }
  return(AUC)
}

#' @rdname auc
#' @export
auc.glm <- function(modelObject, ...){

  family <- family(modelObject)[[1]]
  if(any(family %in% c('binomial', 'poisson'))){
    actual <- modelObject$y
    predicted <- modelObject$fitted.values
  } else {
    stop(paste0("family: ", family, " is not currently supported"))
  }

  auc.default(actual, predicted)
}

#' @rdname auc
#' @export
auc.randomForest <- function(modelObject, ...){

  actual <- as.numeric(modelObject$y) - 1
  predicted <- predict(modelObject, type = 'prob')[,2]

  auc.default(actual, predicted)
}

#' @rdname auc
#' @export
auc.glmerMod <- function(modelObject, ...){

  actual <- modelObject@resp$y
  predicted <- modelObject@resp$mu

  auc.default(actual, predicted)
}

#' @rdname auc
#' @export
auc.gbm <- function(modelObject, ...){

  actual <- modelObject$data$y
  predicted <- modelObject$fit

  auc.default(actual, predicted)
}

#' @rdname auc
#' @export
auc.rpart <- function(modelObject, ...){

  actual <- modelObject$y
  predicted <- predict(modelObject)

  auc.default(actual, predicted)
}

context("auc Tests")

test_that("auc binary error", {

  Levs = 8
  Size = 100
  y = sample(1:Levs, Size, replace = TRUE)

  xm = matrix(runif(Levs*Size), ncol = Levs)
  xm = xm/rowSums(xm)

  expect_error(auc(y, xm)
    , "auc only works for binary outcomes at this time")

})


test_that("mauc", {

  Levs = 8
  Size = 100
  y = sample(1:Levs, Size, replace = TRUE)

  xm = matrix(runif(Levs*Size), ncol = Levs)
  xm = xm/rowSums(xm)
  # no warnings
  expect_silent(res1 <- mauc(y, xm))
  # estimated
  expect_true(!is.nan(res1$mauc))

  expect_silent(res2 <- mauc(y, as.data.frame(xm)))
  expect_true(res1$mauc == res2$mauc)
  expect_true(all(res1$auc == res2$auc))

  expect_silent(res3 <- mauc(as.character(y), as.data.frame(xm)))
  expect_true(res1$mauc == res3$mauc)
  expect_true(all(res1$auc == res3$auc))

  expect_silent(res4 <- mauc(as.factor(y), as.data.frame(xm)))
  expect_true(res1$mauc == res4$mauc)
  expect_true(all(res1$auc == res4$auc))

})

#' @title GINI Coefficient
#'
#' @description Calculates the GINI coefficient for a binary classifcation model
#'
#' @param actual A vector of the labels. Can be \code{numeric, character, or factor}
#' @param predicted A vector of predicted values
#' @param \dots additional parameters to be passed the the s3 methods
#' @param modelObject the model object. Currently supported \code{glm, randomForest, glmerMod, gbm}
#'
#' @examples
#' data(testDF)
#' glmModel <- glm(y ~ ., data = testDF, family="binomial")
#' Preds <- predict(glmModel, type = 'response')
#'
#' gini(testDF$y, Preds)
#' # using s3 method for glm
#' gini(glmModel)
#'
#' @export

gini <- function(...){
  UseMethod("gini")
}

#' @rdname gini
#' @importFrom data.table fsort
#' @export
gini.default <- function(actual, predicted, ...){

  df1 <- data.frame(actual = actual, predicted = predicted)
  df2 <- data.frame(actual = actual, predicted = actual)
  df1 <- df1[order(-df1$predicted),]
  df2 <- df2[order(-df2$actual),]
  gini <- gini_(df1$actual)/gini_(df2$actual)
  return(gini)
}

#' @rdname gini
#' @export
gini.glm <- function(modelObject, ...){

  family <- family(modelObject)[[1]]
  if(any(family %in% c('binomial', 'poisson'))){
    actual <- modelObject$y
    predicted <- modelObject$fitted.values
  } else {
    stop(paste0("family: ", family, " is not currently supported"))
  }

  gini.default(actual, predicted)
}

#' @importFrom stats predict
#' @rdname gini
#' @export
gini.randomForest <- function(modelObject, ...){

  actual <- as.numeric(modelObject$y) - 1
  predicted <- predict(modelObject, type = 'prob')[,2]

  gini.default(actual, predicted)
}

#' @rdname gini
#' @export
gini.glmerMod <- function(modelObject, ...){

  actual <- modelObject@resp$y
  predicted <- modelObject@resp$mu

  gini.default(actual, predicted)
}

#' @rdname gini
#' @export
gini.gbm <- function(modelObject, ...){

  actual <- modelObject$data$y
  predicted <- modelObject$fit

  gini.default(actual, predicted)
}

#' @rdname gini
#' @export
gini.rpart <- function(modelObject, ...){

  actual <- modelObject$y
  predicted <- predict(modelObject)

  gini.default(actual, predicted)
}

# Generated by using Rcpp::compileAttributes() -> do not edit by hand
# Generator token: 10BE3573-1514-4C36-9D1C-5A225CD40393

avg_rank <- function(x) {
    .Call('_ModelMetrics_avg_rank', PACKAGE = 'ModelMetrics', x)
}

auc_ <- function(actual, predicted) {
    .Call('_ModelMetrics_auc_', PACKAGE = 'ModelMetrics', actual, predicted)
}

auc2_ <- function(actual, predicted) {
    .Call('_ModelMetrics_auc2_', PACKAGE = 'ModelMetrics', actual, predicted)
}

auc3_ <- function(actual, predicted, ranks) {
    .Call('_ModelMetrics_auc3_', PACKAGE = 'ModelMetrics', actual, predicted, ranks)
}

confusionMatrix_ <- function(actual, predicted, cutoff) {
    .Call('_ModelMetrics_confusionMatrix_', PACKAGE = 'ModelMetrics', actual, predicted, cutoff)
}

ppv_ <- function(actual, predicted, cutoff) {
    .Call('_ModelMetrics_ppv_', PACKAGE = 'ModelMetrics', actual, predicted, cutoff)
}

npv_ <- function(actual, predicted, cutoff) {
    .Call('_ModelMetrics_npv_', PACKAGE = 'ModelMetrics', actual, predicted, cutoff)
}

tnr_ <- function(actual, predicted, cutoff) {
    .Call('_ModelMetrics_tnr_', PACKAGE = 'ModelMetrics', actual, predicted, cutoff)
}

recall_ <- function(actual, predicted, cutoff) {
    .Call('_ModelMetrics_recall_', PACKAGE = 'ModelMetrics', actual, predicted, cutoff)
}

fScore_ <- function(actual, predicted, cutoff, beta) {
    .Call('_ModelMetrics_fScore_', PACKAGE = 'ModelMetrics', actual, predicted, cutoff, beta)
}

f1Score_ <- function(actual, predicted, cutoff) {
    .Call('_ModelMetrics_f1Score_', PACKAGE = 'ModelMetrics', actual, predicted, cutoff)
}

brier_ <- function(actual, predicted) {
    .Call('_ModelMetrics_brier_', PACKAGE = 'ModelMetrics', actual, predicted)
}

mcc_ <- function(actual, predicted, cutoff) {
    .Call('_ModelMetrics_mcc_', PACKAGE = 'ModelMetrics', actual, predicted, cutoff)
}

kappa_ <- function(actual, predicted, cutoff) {
    .Call('_ModelMetrics_kappa_', PACKAGE = 'ModelMetrics', actual, predicted, cutoff)
}

mae_ <- function(actual, predicted) {
    .Call('_ModelMetrics_mae_', PACKAGE = 'ModelMetrics', actual, predicted)
}

ce_ <- function(actual, predicted) {
    .Call('_ModelMetrics_ce_', PACKAGE = 'ModelMetrics', actual, predicted)
}

mse_ <- function(actual, predicted) {
    .Call('_ModelMetrics_mse_', PACKAGE = 'ModelMetrics', actual, predicted)
}

msle_ <- function(actual, predicted) {
    .Call('_ModelMetrics_msle_', PACKAGE = 'ModelMetrics', actual, predicted)
}

rmsle_ <- function(actual, predicted) {
    .Call('_ModelMetrics_rmsle_', PACKAGE = 'ModelMetrics', actual, predicted)
}

rmse_ <- function(actual, predicted) {
    .Call('_ModelMetrics_rmse_', PACKAGE = 'ModelMetrics', actual, predicted)
}

gini_ <- function(actual) {
    .Call('_ModelMetrics_gini_', PACKAGE = 'ModelMetrics', actual)
}

logLoss_ <- function(actual, predicted) {
    .Call('_ModelMetrics_logLoss_', PACKAGE = 'ModelMetrics', actual, predicted)
}

mlogLoss_ <- function(actual, predicted) {
    .Call('_ModelMetrics_mlogLoss_', PACKAGE = 'ModelMetrics', actual, predicted)
}

plogLoss_ <- function(actual, predicted) {
    .Call('_ModelMetrics_plogLoss_', PACKAGE = 'ModelMetrics', actual, predicted)
}

#' @useDynLib ModelMetrics
#' @importFrom Rcpp sourceCpp
NULL

#' Test data
#'
#' @name testDF
#' @docType data
NULL


#' @title Multiclass Log Loss
#'
#' @description Calculated the multi-class log loss
#'
#' @param actual A vector of the labels. Can be \code{numeric, character, or factor}
#' @param predicted matrix of predicted values. Can be \code{matrix, data.frame}
#'
#' @export

mlogLoss <- function(actual, predicted){

  if(inherits(actual, c('factor', 'character'))){
    actual = as.numeric(as.factor(actual))
  }
  if(inherits(predicted, c('data.frame'))){
    predicted = as.matrix(predicted)
  }

  eps <- 1e-15
  predicted = pmax(pmin(predicted, 1 - eps), eps)

  mlogLoss_(actual, predicted)
}


#' @title Multiclass Area Under the Curve
#'
#' @description Calculates the area under the curve for a binary classifcation model
#'
#' @param actual A vector of the labels. Can be \code{numeric, character, or factor}
#' @param predicted A data.frame of predicted values. Can be \code{matrix, data.frame}
#'
#'
#' @examples
#' setosa <- glm(I(Species == 'setosa') ~ Sepal.Length, data = iris, family = 'binomial')
#' versicolor <- glm(I(Species == 'versicolor') ~ Sepal.Length, data = iris, family = 'binomial')
#' virginica <- glm(I(Species == 'virginica') ~ Sepal.Length, data = iris, family = 'binomial')
#'
#' Pred <-
#'   data.frame(
#'     setosa = predict(setosa, type = 'response')
#'     ,versicolor = predict(versicolor, type = 'response')
#'     ,virginica = predict(virginica, type = 'response')
#'   )
#'
#' Predicted = Pred/rowSums(Pred)
#' Actual = iris$Species
#'
#' mauc(Actual, Predicted)
#'
#' @export

mauc <- function(actual, predicted){

  actual <- factor(actual)
  Data <- data.frame(predicted, actual)
  Outcomes <- length(unique(actual))

  simpleAUC <- function(x){
    # One-vs-all
    y1 = levels(Data$actual)[x]
    y  <- as.numeric(Data[, "actual"] == y1)
    prob <- Data[,x]
    AUCs <- auc(y, prob)
    return(AUCs)
  }

  AUCs <- sapply(1:Outcomes, simpleAUC)
  list(mauc = mean(AUCs), auc = AUCs)

}


#' @title Confusion Matrix
#' @description Create a confusion matrix given a specific cutoff.
#'
#' @param actual A vector of the labels
#' @param predicted A vector of predicted values
#' @param cutoff A cutoff for the predicted values
#'
#' @export

confusionMatrix <- function(actual, predicted, cutoff = .5){
  confusionMatrix_(actual, predicted, cutoff)
}



#' @title Positive Predictive Value
#'
#' @description True Positives / (True Positives + False Positives)
#'
#' @aliases precision
#'
#' @param actual A vector of the labels
#' @param predicted A vector of predicted values
#' @param cutoff A cutoff for the predicted values
#'
#' @examples
#' data(testDF)
#' glmModel <- glm(y ~ ., data = testDF, family="binomial")
#' Preds <- predict(glmModel, type = 'response')
#'
#' ppv(testDF$y, Preds, cutoff = 0)
#' precision(testDF$y, Preds, cutoff = 0)
#'
#' @export

ppv <- function(actual, predicted, cutoff = .5){
  ppv_(actual, predicted, cutoff)
}

#' @export

precision <- function(actual, predicted, cutoff = .5){
  ppv_(actual, predicted, cutoff)
}




#' @title Negative Predictive Value
#'
#' @description True Negatives / (True Negatives + False Negatives)
#'
#' @param actual A vector of the labels
#' @param predicted A vector of predicted values
#' @param cutoff A cutoff for the predicted values
#'
#' @examples
#' data(testDF)
#' glmModel <- glm(y ~ ., data = testDF, family="binomial")
#' Preds <- predict(glmModel, type = 'response')
#'
#' npv(testDF$y, Preds, cutoff = 0)
#'
#' @export

npv <- function(actual, predicted, cutoff = .5){
  npv_(actual, predicted, cutoff)
}



#' @title Recall, Sensitivity, tpr
#'
#' @aliases sensitivity tpr
#'
#' @description True Positives / (True Positives + False Negatives)
#'
#' @param actual A vector of the labels
#' @param predicted A vector of predicted values
#' @param cutoff A cutoff for the predicted values
#'
#' @examples
#' data(testDF)
#' glmModel <- glm(y ~ ., data = testDF, family="binomial")
#' Preds <- predict(glmModel, type = 'response')
#'
#' recall(testDF$y, Preds, cutoff = 0)
#' sensitivity(testDF$y, Preds, cutoff = 0)
#' tpr(testDF$y, Preds, cutoff = 0)
#'
#' @export

recall <- function(actual, predicted, cutoff = .5){
  recall_(actual, predicted, cutoff)
}

#' @export
sensitivity <- function(actual, predicted, cutoff = .5){
  recall_(actual, predicted, cutoff)
}

#' @export
tpr <- function(actual, predicted, cutoff = .5){
  recall_(actual, predicted, cutoff)
}


#' @title Specificity, True negative rate
#'
#' @aliases specificity tnr
#'
#' @description True Negatives / (True Negatives + False Positives)
#'
#' @param actual A vector of the labels
#' @param predicted A vector of predicted values
#' @param cutoff A cutoff for the predicted values
#'
#' @examples
#' data(testDF)
#' glmModel <- glm(y ~ ., data = testDF, family="binomial")
#' Preds <- predict(glmModel, type = 'response')
#'
#' tnr(testDF$y, Preds, cutoff = 0)
#' specificity(testDF$y, Preds, cutoff = 0)
#'
#' @export

tnr <- function(actual, predicted, cutoff = .5){
  tnr_(actual, predicted, cutoff)
}

#' @export
specificity <- function(actual, predicted, cutoff = .5){
  tnr_(actual, predicted, cutoff)
}


#' @title F1 Score
#' @description Calculates the f1 score
#'
#' @param actual A vector of the labels
#' @param predicted A vector of predicted values
#' @param cutoff A cutoff for the predicted values
#'
#' @export

f1Score <- function(actual, predicted, cutoff = .5){

  f1Score_(actual, predicted, cutoff)

}

#' @title F Score
#' @description Calculates the F score and allows different specifications of the beta value (F0.5)
#'
#' @param actual A vector of the labels
#' @param predicted A vector of predicted values
#' @param cutoff A cutoff for the predicted values
#' @param beta the desired beta value (lower increases weight of precision over recall). Defaults to 1
#'
#' @export

fScore <- function(actual, predicted, cutoff = .5, beta = 1){

  fScore_(actual, predicted, cutoff, beta)

}


#' @title Matthews Correlation Coefficient
#' @description Calculates the Matthews Correlation Coefficient
#'
#' @param actual A vector of the labels
#' @param predicted A vector of predicted values
#' @param cutoff A cutoff for the predicted values
#'
#' @export

mcc <- function(actual, predicted, cutoff){
  mcc_(actual, predicted, cutoff)
}




#' @title kappa statistic
#'
#' @description Calculates kappa statistic. Currently build to handle binary values in \code{actual} vector.
#'
#' @param actual A vector of the labels
#' @param predicted A vector of predicted values
#' @param cutoff A cutoff for the predicted values
#'
#' @export

kappa <- function(actual, predicted, cutoff = .5){
  kappa_(actual, predicted, cutoff)
}

context("Calculation Tests")
data(testDF)
glmModel <- glm(y ~ ., data=testDF, family="binomial")
Preds <- predict(glmModel, type = 'response')


test_that("logLoss returns correct values", {

  expect_equal(logLoss(testDF$y, Preds), 0.1546854, tolerance = .000001)
  expect_equal(logLoss(testDF$y, Preds, 'poisson'), 0.6910357, tolerance = .000001)
  expect_equal(logLoss(glmModel), 0.1546854, tolerance = .000001)

})


test_that("auc returns correct values", {

  expect_equal(auc(testDF$y, Preds), 0.9872666, tolerance = .000001)
  expect_equal(auc(c(testDF$y,testDF$y), c(Preds, Preds)), 0.9872666, tolerance = .000001)
  expect_equal(auc(glmModel), 0.9872666, tolerance = .000001)

})

test_that("gini returns correct values", {

  expect_equal(gini(testDF$y, Preds), 0.9745332, tolerance = .000001)
  expect_equal(gini(c(testDF$y,testDF$y), c(Preds, Preds)), 0.9745332, tolerance = .000001)
  expect_equal(gini(glmModel), 0.9745332, tolerance = .000001)

})


test_that("rmse returns correct values", {

  expect_equal(rmse(testDF$y, Preds), 0.2188343, tolerance = .000001)
  expect_equal(rmse(glmModel), 0.2188343, tolerance = .000001)

})


test_that("mse returns correct values", {

  expect_equal(mse(testDF$y, Preds), 0.04788846, tolerance = .000001)
  expect_equal(mse(glmModel), 0.04788846, tolerance = .000001)

})


test_that("ppv returns correct values", {

  expect_equal(ppv(testDF$y, Preds, .5), 0.9365079, tolerance = .000001)
  expect_equal(precision(testDF$y, Preds, .5), 0.9365079, tolerance = .000001)

})


test_that("npv returns correct values", {

  expect_equal(npv(testDF$y, Preds, .5), 0.9189189, tolerance = .000001)

})


test_that("specificity returns correct values", {

  tempTab <- table(testDF$y, Preds > .5)
  SPC <- tempTab[1,1]/sum(tempTab[1,])

  expect_equal(specificity(testDF$y, Preds, .5), SPC, tolerance = .000001)
  expect_equal(tnr(testDF$y, Preds, .5), SPC, tolerance = .000001)

})


test_that("sensitivity returns correct values", {

  expect_equal(recall(testDF$y, Preds, .5), 0.9516129, tolerance = .000001)
  expect_equal(sensitivity(testDF$y, Preds, .5), 0.9516129, tolerance = .000001)
  expect_equal(tpr(testDF$y, Preds, .5), 0.9516129, tolerance = .000001)

})

test_that("f1 score returns correct values", {

  expect_equal(f1Score(testDF$y, Preds, .5), 0.944, tolerance = .000001)

})

test_that("f1 score and F score agree with beta 1 (default value)", {

  expect_equal(f1Score(testDF$y, Preds, .5), fScore(testDF$y, Preds, .5, 1), tolerance = .000001)

})

test_that("mcc returns correct values", {

  expect_equal(mcc(testDF$y, Preds, .5), 0.8508762, tolerance = .000001)

})


test_that("brier returns correct values", {

  expect_equal(brier(testDF$y, Preds), 0.04788846, tolerance = .000001)
  expect_equal(brier(glmModel), 0.04788846, tolerance = .000001)

})



test_that("mae returns correct values", {

  expect_equal(mae(testDF$y, Preds), 0.09440662, tolerance = .000001)
  expect_equal(mae(glmModel), 0.09440662, tolerance = .000001)

})


test_that("msle returns correct values", {

  expect_equal(msle(testDF$y, Preds), 0.02318011, tolerance = .000001)
  expect_equal(msle(glmModel), 0.02318011, tolerance = .000001)

})


test_that("rmsle returns correct values", {

  expect_equal(rmsle(testDF$y, Preds), 0.1522501, tolerance = .000001)
  expect_equal(rmsle(glmModel), 0.1522501, tolerance = .000001)


})


test_that("rmsle returns correct values", {

  A <- c(rep(1, 63), rep(0, 31))
  B <- c(rep(1, 61), rep(0, 25), rep(1, 6), rep(0, 2))

  tab <- table(A, B)

  a = tab[2,2]
  b = tab[2,1]
  c = tab[1,2]
  d = tab[1,1]

  marginA = ((a + b)*(a + c))/(a + b + c + d)
  marginB = ((c + d)*(b + d))/(a + b + c + d)

  Pe = (marginA + marginB)/(a + b + c + d)
  Po = (a + d)/(a + b + c + d)

  manualKappa = (Po - Pe)/(1 - Pe)

  expect_equal(kappa(A, B), manualKappa, tolerance = .000001)


})

context("logLoss Tests")

test_that("mlogLoss character/factor actual", {

  Levs = 8
  Size = 100
  y = sample(1:Levs, Size, replace = TRUE)

  xm = matrix(runif(Levs*Size), ncol = Levs)
  xm = xm/rowSums(xm)

  m1 <- mlogLoss(y, xm)
  m2 <- mlogLoss(as.character(y), xm)
  m3 <- mlogLoss(as.factor(y), xm)

  expect_true(m1 == m2)
  expect_true(m1 == m3)

})


test_that("mlogLoss different classes", {

  Levs = 8
  Size = 100
  y = sample(1:Levs, Size, replace = TRUE)

  xm = matrix(runif(Levs*Size), ncol = Levs)
  xm = xm/rowSums(xm)

  # no warnings
  expect_silent(res1 <- mlogLoss(y, xm))
  # estimated
  expect_true(!is.nan(res1))

  expect_silent(res2 <- mlogLoss(y, as.data.frame(xm)))
  expect_true(res1 == res2)
  expect_true(all(res1 == res2))

  expect_silent(res3 <- mlogLoss(as.character(y), as.data.frame(xm)))
  expect_true(res1 == res3)
  expect_true(all(res1 == res3))

  expect_silent(res4 <- mlogLoss(as.factor(y), as.data.frame(xm)))
  expect_true(res1 == res4)
  expect_true(all(res1 == res4))


  ## test taken from caret written by Max Kuhn
  eps <- 1e-15

  classes <- LETTERS[1:3]

  test_dat1 <- data.frame(obs  = c("A", "A", "A", "B", "B", "C"),
                          pred = c("A", "A", "A", "B", "B", "C"),
                          A = c(1, .80, .51, .1, .2, .3),
                          B = c(0, .05, .29, .8, .6, .3),
                          C = c(0, .15, .20, .1, .2, .4))

  expected1 <- log(1-eps) + log(.8) + log(.51) + log(.8) + log(.6) + log(.4)
  expected1 <- -expected1/nrow(test_dat1)
  result1 <- mlogLoss(test_dat1$obs, test_dat1[,3:5])

  # test_dat2 <- test_dat1
  # test_dat2$A[1] <- NA
  #
  # expected2 <-  log(.8) + log(.51) + log(.8) + log(.6) + log(.4)
  # expected2 <- c(logLoss = -expected2/sum(complete.cases(test_dat2)))
  # result2 <- mlogLoss(test_dat2$obs, test_dat2[,3:5])

  expect_equal(result1, expected1)
  # expect_equal(result2, expected2)
  # expect_equal(result3, expected3)

})



test_that("mauc", {

  Levs = 8
  Size = 100
  y = sample(1:Levs, Size, replace = TRUE)

  xm = matrix(runif(Levs*Size), ncol = Levs)
  xm = xm/rowSums(xm)
  # no warnings
  expect_silent(res1 <- mauc(y, xm))
  # estimated
  expect_true(!is.nan(res1$mauc))

  expect_silent(res2 <- mauc(y, as.data.frame(xm)))
  expect_true(res1$mauc == res2$mauc)
  expect_true(all(res1$auc == res2$auc))

  expect_silent(res3 <- mauc(as.character(y), as.data.frame(xm)))
  expect_true(res1$mauc == res3$mauc)
  expect_true(all(res1$auc == res3$auc))

  expect_silent(res4 <- mauc(as.factor(y), as.data.frame(xm)))
  expect_true(res1$mauc == res4$mauc)
  expect_true(all(res1$auc == res4$auc))

})



test_that("logLoss estimates with 0s and 1s as values", {

  data(testDF)
  glmModel <- glm(y ~ ., data=testDF, family="binomial")
  Preds <- predict(glmModel, type = 'response')

  Preds[1] = 0
  Preds[2] = 1
  logLoss(testDF$y, Preds)

})

#' @title Mean Square Error
#' @description Calculates the mean square error
#'
#' @param actual A vector of the labels
#' @param predicted A vector of predicted values
#' @param \dots additional parameters to be passed the the s3 methods
#' @param modelObject the model object. Currently supported \code{lm}
#'
#' @examples
#' data(testDF)
#' glmModel <- glm(y ~ ., data = testDF, family="binomial")
#' Preds <- predict(glmModel, type = 'response')
#'
#' mse(testDF$y, Preds)
#'
#' @export

mse <- function(...){
  UseMethod("mse")
}

#' @rdname mse
#' @export
mse.default <- function(actual, predicted, ...){
  mse_(actual, predicted)
}

#' @rdname mse
#' @export
mse.lm <- function(modelObject, ...){

  predicted <- modelObject$fitted.values
  actual <- modelObject$residuals + predicted

  mse.default(actual, predicted)
}

#' @rdname mse
#' @export
mse.glm <- function(modelObject, ...){

  family <- family(modelObject)[[1]]
  if(any(family %in% c('binomial', 'poisson'))){
    actual <- modelObject$y
    predicted <- modelObject$fitted.values
  } else {
    stop(paste0("family: ", family, " is not currently supported"))
  }

  mse.default(actual, predicted)
}


#' @title Root-Mean Square Error
#' @description Calculates the root mean square error
#'
#' @param actual A vector of the labels
#' @param predicted A vector of predicted values
#' @param \dots additional parameters to be passed the the s3 methods
#' @param modelObject the model object. Currently supported \code{lm}
#'
#' @examples
#' data(testDF)
#' glmModel <- glm(y ~ ., data = testDF, family="binomial")
#' Preds <- predict(glmModel, type = 'response')
#'
#' rmse(testDF$y, Preds)
#'
#' @export


rmse <- function(...){
  UseMethod("rmse")
}

#' @rdname rmse
#' @export
rmse.default <- function(actual, predicted, ...){
  rmse_(actual, predicted)
}

#' @rdname rmse
#' @export
rmse.lm <- function(modelObject, ...){

  predicted <- modelObject$fitted.values
  actual <- modelObject$residuals + predicted

  rmse.default(actual, predicted)
}

#' @rdname rmse
#' @export
rmse.glm <- function(modelObject, ...){

  family <- family(modelObject)[[1]]
  if(any(family %in% c('binomial', 'poisson'))){
    actual <- modelObject$y
    predicted <- modelObject$fitted.values
  } else {
    stop(paste0("family: ", family, " is not currently supported"))
  }

  rmse.default(actual, predicted)
}

#' @title Brier Score
#' @description Calculates the Brier score
#'
#' @param actual A vector of the labels
#' @param predicted A vector of predicted values
#' @param \dots additional parameters to be passed the the s3 methods
#' @param modelObject the model object. Currently supported \code{glm, randomForest, glmerMod, gbm}
#'
#' @export

brier <- function(...){
  UseMethod("brier")
}

#' @rdname brier
#' @export
brier.default <- function(actual, predicted, ...){
  brier_(actual, predicted)
}


#' @rdname brier
#' @export
brier.glm <- function(modelObject, ...){

  family <- family(modelObject)[[1]]
  if(any(family %in% c('binomial', 'poisson'))){
    actual <- modelObject$y
    predicted <- modelObject$fitted.values
  } else {
    stop(paste0("family: ", family, " is not currently supported"))
  }

  brier.default(actual, predicted)
}

#' @rdname brier
#' @export
brier.randomForest <- function(modelObject, ...){

  actual <- as.numeric(modelObject$y) - 1
  predicted <- predict(modelObject, type = 'prob')[,2]

  brier.default(actual, predicted)
}

#' @rdname brier
#' @export
brier.glmerMod <- function(modelObject, ...){

  actual <- modelObject@resp$y
  predicted <- modelObject@resp$mu

  brier.default(actual, predicted)
}

#' @rdname brier
#' @export
brier.gbm <- function(modelObject, ...){

  actual <- modelObject$data$y
  predicted <- modelObject$fit

  brier.default(actual, predicted)
}

#' @rdname brier
#' @export
brier.rpart <- function(modelObject, ...){

  actual <- modelObject$y
  predicted <- predict(modelObject)

  brier.default(actual, predicted)
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/ModelMetrics.R
\name{mcc}
\alias{mcc}
\title{Matthews Correlation Coefficient}
\usage{
mcc(actual, predicted, cutoff)
}
\arguments{
\item{actual}{A vector of the labels}

\item{predicted}{A vector of predicted values}

\item{cutoff}{A cutoff for the predicted values}
}
\description{
Calculates the Matthews Correlation Coefficient
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/brier.R
\name{brier}
\alias{brier}
\alias{brier.default}
\alias{brier.glm}
\alias{brier.randomForest}
\alias{brier.glmerMod}
\alias{brier.gbm}
\alias{brier.rpart}
\title{Brier Score}
\usage{
brier(...)

\method{brier}{default}(actual, predicted, ...)

\method{brier}{glm}(modelObject, ...)

\method{brier}{randomForest}(modelObject, ...)

\method{brier}{glmerMod}(modelObject, ...)

\method{brier}{gbm}(modelObject, ...)

\method{brier}{rpart}(modelObject, ...)
}
\arguments{
\item{\dots}{additional parameters to be passed the the s3 methods}

\item{actual}{A vector of the labels}

\item{predicted}{A vector of predicted values}

\item{modelObject}{the model object. Currently supported \code{glm, randomForest, glmerMod, gbm}}
}
\description{
Calculates the Brier score
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/ModelMetrics.R
\name{mlogLoss}
\alias{mlogLoss}
\title{Multiclass Log Loss}
\usage{
mlogLoss(actual, predicted)
}
\arguments{
\item{actual}{A vector of the labels. Can be \code{numeric, character, or factor}}

\item{predicted}{matrix of predicted values. Can be \code{matrix, data.frame}}
}
\description{
Calculated the multi-class log loss
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/logLoss.R
\name{logLoss}
\alias{logLoss}
\alias{logLoss.default}
\alias{logLoss.glm}
\alias{logLoss.randomForest}
\alias{logLoss.glmerMod}
\alias{logLoss.gbm}
\alias{logLoss.rpart}
\title{Log Loss}
\usage{
logLoss(...)

\method{logLoss}{default}(actual, predicted, distribution = "binomial", ...)

\method{logLoss}{glm}(modelObject, ...)

\method{logLoss}{randomForest}(modelObject, ...)

\method{logLoss}{glmerMod}(modelObject, ...)

\method{logLoss}{gbm}(modelObject, ...)

\method{logLoss}{rpart}(modelObject, ...)
}
\arguments{
\item{\dots}{additional parameters to be passed the the s3 methods}

\item{actual}{a binary vector of the labels}

\item{predicted}{a vector of predicted values}

\item{distribution}{the distribution of the loss function needed \code{binomial, poisson}}

\item{modelObject}{the model object. Currently supported \code{glm, randomForest, glmerMod, gbm}}
}
\description{
Calculates the log loss or entropy loss for a binary outcome
}
\examples{
data(testDF)
glmModel <- glm(y ~ ., data = testDF, family="binomial")
Preds <- predict(glmModel, type = 'response')

logLoss(testDF$y, Preds)
# using s3 method for glm
logLoss(glmModel)

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/auc.R
\name{auc}
\alias{auc}
\alias{auc.default}
\alias{auc.glm}
\alias{auc.randomForest}
\alias{auc.glmerMod}
\alias{auc.gbm}
\alias{auc.rpart}
\title{Area Under the Curve}
\usage{
auc(...)

\method{auc}{default}(actual, predicted, ...)

\method{auc}{glm}(modelObject, ...)

\method{auc}{randomForest}(modelObject, ...)

\method{auc}{glmerMod}(modelObject, ...)

\method{auc}{gbm}(modelObject, ...)

\method{auc}{rpart}(modelObject, ...)
}
\arguments{
\item{\dots}{additional parameters to be passed the the s3 methods}

\item{actual}{A vector of the labels. Can be \code{numeric, character, or factor}}

\item{predicted}{A vector of predicted values}

\item{modelObject}{the model object. Currently supported \code{glm, randomForest, glmerMod, gbm}}
}
\description{
Calculates the area under the curve for a binary classifcation model
}
\examples{
data(testDF)
glmModel <- glm(y ~ ., data = testDF, family="binomial")
Preds <- predict(glmModel, type = 'response')

auc(testDF$y, Preds)
# using s3 method for glm
auc(glmModel)


}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/mse.R
\name{rmse}
\alias{rmse}
\alias{rmse.default}
\alias{rmse.lm}
\alias{rmse.glm}
\title{Root-Mean Square Error}
\usage{
rmse(...)

\method{rmse}{default}(actual, predicted, ...)

\method{rmse}{lm}(modelObject, ...)

\method{rmse}{glm}(modelObject, ...)
}
\arguments{
\item{\dots}{additional parameters to be passed the the s3 methods}

\item{actual}{A vector of the labels}

\item{predicted}{A vector of predicted values}

\item{modelObject}{the model object. Currently supported \code{lm}}
}
\description{
Calculates the root mean square error
}
\examples{
data(testDF)
glmModel <- glm(y ~ ., data = testDF, family="binomial")
Preds <- predict(glmModel, type = 'response')

rmse(testDF$y, Preds)

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/ModelMetrics.R
\name{ppv}
\alias{ppv}
\alias{precision}
\title{Positive Predictive Value}
\usage{
ppv(actual, predicted, cutoff = 0.5)
}
\arguments{
\item{actual}{A vector of the labels}

\item{predicted}{A vector of predicted values}

\item{cutoff}{A cutoff for the predicted values}
}
\description{
True Positives / (True Positives + False Positives)
}
\examples{
data(testDF)
glmModel <- glm(y ~ ., data = testDF, family="binomial")
Preds <- predict(glmModel, type = 'response')

ppv(testDF$y, Preds, cutoff = 0)
precision(testDF$y, Preds, cutoff = 0)

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/ce.R
\name{ce}
\alias{ce}
\alias{ce.default}
\alias{ce.lm}
\alias{ce.glm}
\alias{ce.randomForest}
\alias{ce.glmerMod}
\alias{ce.gbm}
\alias{ce.rpart}
\title{Classification error}
\usage{
ce(...)

\method{ce}{default}(actual, predicted, ...)

\method{ce}{lm}(modelObject, ...)

\method{ce}{glm}(modelObject, ...)

\method{ce}{randomForest}(modelObject, ...)

\method{ce}{glmerMod}(modelObject, ...)

\method{ce}{gbm}(modelObject, ...)

\method{ce}{rpart}(modelObject, ...)
}
\arguments{
\item{\dots}{additional parameters to be passed the the s3 methods}

\item{actual}{A vector of the labels}

\item{predicted}{A vector of predicted values}

\item{modelObject}{the model object. Currently supported \code{lm, glm, randomForest, glmerMod, gbm, rpart}}
}
\description{
Calculates the classification error
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/gini.R
\name{gini}
\alias{gini}
\alias{gini.default}
\alias{gini.glm}
\alias{gini.randomForest}
\alias{gini.glmerMod}
\alias{gini.gbm}
\alias{gini.rpart}
\title{GINI Coefficient}
\usage{
gini(...)

\method{gini}{default}(actual, predicted, ...)

\method{gini}{glm}(modelObject, ...)

\method{gini}{randomForest}(modelObject, ...)

\method{gini}{glmerMod}(modelObject, ...)

\method{gini}{gbm}(modelObject, ...)

\method{gini}{rpart}(modelObject, ...)
}
\arguments{
\item{\dots}{additional parameters to be passed the the s3 methods}

\item{actual}{A vector of the labels. Can be \code{numeric, character, or factor}}

\item{predicted}{A vector of predicted values}

\item{modelObject}{the model object. Currently supported \code{glm, randomForest, glmerMod, gbm}}
}
\description{
Calculates the GINI coefficient for a binary classifcation model
}
\examples{
data(testDF)
glmModel <- glm(y ~ ., data = testDF, family="binomial")
Preds <- predict(glmModel, type = 'response')

gini(testDF$y, Preds)
# using s3 method for glm
gini(glmModel)

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/mae.R
\name{mae}
\alias{mae}
\alias{mae.default}
\alias{mae.glm}
\alias{mae.randomForest}
\alias{mae.glmerMod}
\alias{mae.gbm}
\alias{mae.rpart}
\title{Mean absolute error}
\usage{
mae(...)

\method{mae}{default}(actual, predicted, ...)

\method{mae}{glm}(modelObject, ...)

\method{mae}{randomForest}(modelObject, ...)

\method{mae}{glmerMod}(modelObject, ...)

\method{mae}{gbm}(modelObject, ...)

\method{mae}{rpart}(modelObject, ...)
}
\arguments{
\item{\dots}{additional parameters to be passed the the s3 methods}

\item{actual}{A vector of the labels}

\item{predicted}{A vector of predicted values}

\item{modelObject}{the model object. Currently supported \code{glm, randomForest, glmerMod, gbm}}
}
\description{
Calculates the mean absolute error
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/ModelMetrics.R
\name{fScore}
\alias{fScore}
\title{F Score}
\usage{
fScore(actual, predicted, cutoff = 0.5, beta = 1)
}
\arguments{
\item{actual}{A vector of the labels}

\item{predicted}{A vector of predicted values}

\item{cutoff}{A cutoff for the predicted values}

\item{beta}{the desired beta value (lower increases weight of precision over recall). Defaults to 1}
}
\description{
Calculates the F score and allows different specifications of the beta value (F0.5)
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/msle.R
\name{msle}
\alias{msle}
\alias{msle.default}
\alias{msle.lm}
\alias{msle.glm}
\alias{msle.randomForest}
\alias{msle.glmerMod}
\alias{msle.gbm}
\alias{msle.rpart}
\title{Mean Squared Log Error}
\usage{
msle(...)

\method{msle}{default}(actual, predicted, ...)

\method{msle}{lm}(modelObject, ...)

\method{msle}{glm}(modelObject, ...)

\method{msle}{randomForest}(modelObject, ...)

\method{msle}{glmerMod}(modelObject, ...)

\method{msle}{gbm}(modelObject, ...)

\method{msle}{rpart}(modelObject, ...)
}
\arguments{
\item{\dots}{additional parameters to be passed the the s3 methods}

\item{actual}{A vector of the labels}

\item{predicted}{A vector of predicted values}

\item{modelObject}{the model object. Currently supported \code{glm, randomForest, glmerMod, gbm}}
}
\description{
Calculates the mean square log error
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/mse.R
\name{mse}
\alias{mse}
\alias{mse.default}
\alias{mse.lm}
\alias{mse.glm}
\title{Mean Square Error}
\usage{
mse(...)

\method{mse}{default}(actual, predicted, ...)

\method{mse}{lm}(modelObject, ...)

\method{mse}{glm}(modelObject, ...)
}
\arguments{
\item{\dots}{additional parameters to be passed the the s3 methods}

\item{actual}{A vector of the labels}

\item{predicted}{A vector of predicted values}

\item{modelObject}{the model object. Currently supported \code{lm}}
}
\description{
Calculates the mean square error
}
\examples{
data(testDF)
glmModel <- glm(y ~ ., data = testDF, family="binomial")
Preds <- predict(glmModel, type = 'response')

mse(testDF$y, Preds)

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/ModelMetrics.R
\name{kappa}
\alias{kappa}
\title{kappa statistic}
\usage{
kappa(actual, predicted, cutoff = 0.5)
}
\arguments{
\item{actual}{A vector of the labels}

\item{predicted}{A vector of predicted values}

\item{cutoff}{A cutoff for the predicted values}
}
\description{
Calculates kappa statistic. Currently build to handle binary values in \code{actual} vector.
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/ModelMetrics.R
\name{mauc}
\alias{mauc}
\title{Multiclass Area Under the Curve}
\usage{
mauc(actual, predicted)
}
\arguments{
\item{actual}{A vector of the labels. Can be \code{numeric, character, or factor}}

\item{predicted}{A data.frame of predicted values. Can be \code{matrix, data.frame}}
}
\description{
Calculates the area under the curve for a binary classifcation model
}
\examples{
setosa <- glm(I(Species == 'setosa') ~ Sepal.Length, data = iris, family = 'binomial')
versicolor <- glm(I(Species == 'versicolor') ~ Sepal.Length, data = iris, family = 'binomial')
virginica <- glm(I(Species == 'virginica') ~ Sepal.Length, data = iris, family = 'binomial')

Pred <-
  data.frame(
    setosa = predict(setosa, type = 'response')
    ,versicolor = predict(versicolor, type = 'response')
    ,virginica = predict(virginica, type = 'response')
  )

Predicted = Pred/rowSums(Pred)
Actual = iris$Species

mauc(Actual, Predicted)

}
